<?php
/**
 * @package     Joomla.Site
 * @subpackage  mod_articles_category
 *
 * @copyright   Copyright (C) 2005 - 2020 Open Source Matters, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

defined('_JEXEC') or die;

?>
<ul class="t4b-list<?php echo $moduleclass_sfx; ?> t4b-grid-layout row">
	<?php foreach ($list as $item) : ?>
		<li class="col-12 col-md-12 col-lg-4">
			<!-- Item image -->
			<?php
			$images = "";
			if (isset($item->images)) {
				$images = json_decode($item->images);
			}

			$imgexists = (isset($images->image_intro) and !empty($images->image_intro)) || (isset($images->image_fulltext) and !empty($images->image_fulltext));

			if ($imgexists) {
				$images->image_intro = $images->image_intro?$images->image_intro:$images->image_fulltext;
			?>

			<a class="item-image" href="<?php echo $item->link; ?>">
				<img src="<?php echo htmlspecialchars($images->image_intro); ?>" alt="<?php echo $item->title; ?>" />
			</a>
			<?php } ?>
			<!-- // Item image -->

			<div class="item-meta">
				<?php if ($item->displayCategoryTitle) : ?>
					<span class="item-cat-title">
						<?php echo $item->displayCategoryTitle; ?>
					</span>
				<?php endif; ?>

				<?php if ($item->displayDate) : ?>
					<span class="item-date">
						<?php echo $item->displayDate; ?>
					</span>
				<?php endif; ?>

				<?php if ($item->displayHits) : ?>
					<span class="item-hits">
						<i class="fa fa-eye" aria-hidden="true"></i><?php echo $item->displayHits; ?>
					</span>
				<?php endif; ?>
			</div>

			<?php if ($params->get('link_titles') == 1) : ?>
				<h3 class="item-title"><a class="mod-articles-category-title <?php echo $item->active; ?>" href="<?php echo $item->link; ?>"><?php echo $item->title; ?></a></h3>
			<?php else : ?>
				<h3><?php echo $item->title; ?></h3>
			<?php endif; ?>

			<?php if ($params->get('show_tags', 0) && $item->tags->itemTags) : ?>
				<div class="item-tags">
					<?php echo JLayoutHelper::render('joomla.content.tags', $item->tags->itemTags); ?>
				</div>
			<?php endif; ?>

			<?php if ($params->get('show_introtext')) : ?>
				<p class="item-introtext">
					<?php echo $item->displayIntrotext; ?>
				</p>
			<?php endif; ?>

			<?php if ($params->get('show_readmore')) : ?>
				<div class="item-readmore">
					<a class="mod-articles-category-title <?php echo $item->active; ?>" href="<?php echo $item->link; ?>">
						<?php if ($item->params->get('access-view') == false) : ?>
							<?php echo JText::_('MOD_ARTICLES_CATEGORY_REGISTER_TO_READ_MORE'); ?>
						<?php elseif ($readmore = $item->alternative_readmore) : ?>
							<?php echo $readmore; ?>
							<?php echo JHtml::_('string.truncate', $item->title, $params->get('readmore_limit')); ?>
						<?php elseif ($params->get('show_readmore_title', 0) == 0) : ?>
							<?php echo JText::sprintf('MOD_ARTICLES_CATEGORY_READ_MORE_TITLE'); ?>
						<?php else : ?>
							<?php echo JText::_('MOD_ARTICLES_CATEGORY_READ_MORE'); ?>
							<?php echo JHtml::_('string.truncate', $item->title, $params->get('readmore_limit')); ?>
						<?php endif; ?>
					</a>
				</div>
			<?php endif; ?>
		</li>
	<?php endforeach; ?>
</ul>

<style>
	.t4b-grid-layout {
		list-style: none;
		padding: 0;
	}

	.t4b-grid-layout > .col-lg-4 {
		margin-bottom: 30px;
	}

	.t4b-grid-layout > .col-lg-4:nth-child(3n+1) {
		clear: both;
	}

	/* Item image */
	.item-image {
		border-radius: 4px;
		display: block;
		margin-bottom: 24px;
		max-height: 220px;
		overflow: hidden;
	}

	.item-image img {
		width: 100%;
	}

	/* Meta */
	.item-meta {
    color: #9E9E9E;
    display: flex;
		align-items: center;
    font-size: 13px;
		margin-bottom: 12px;
	}

	/* Item date */
	.item-date {
    display: flex;
    font-size: 13px;
    margin-right: 8px;
	}

	/* Category */
	.item-cat-title {
		background: #E4F7FF;
    padding: 2px 8px;
    margin-right: 8px;
	}

	.item-cat-title a {
    color: #26B0EB;
    text-decoration: none;
	}

	.category-link {
		background-color: #26b0eb;
		border-color: #26b0eb;
		text-transform: uppercase;
		font-weight: 600;
		letter-spacing: .5px;
		color: #fff;
		padding: 1.06rem 2.857rem;
		font-size: 1rem;
		line-height: 1.7143;
		border-radius: 4px;
	}

	/* Hits */
	.item-hits i {
		margin-right: 3px;
	}

	.item-tags {
		margin-bottom: 12px;
	}

	/* Item title */
	.t4b-grid-layout .item-title {
		color: #262626;
		font-size: 20px;
		line-height: 28px;
		font-weight: 500;
		margin: 0 0 16px;
	}

	.t4b-grid-layout .item-title a {
		color: #262626;
		text-decoration: none;
	}

	.t4b-grid-layout .item-title a:hover,
	.t4b-grid-layout .item-title a:focus,
	.t4b-grid-layout .item-title a:active {
		color: #c96d50;
	}

	/* Intro text */
	.item-introtext {
	}

	/* Read more */
	.t4b-grid-layout .item-readmore a {
		font-weight: 500;
	}
</style>